pub struct ChatAdapter<P: ChatPlatform> { /* private fields */ }Expand description
Chat adapter that converts workflow events to chat messages.
Implementations
Sourceimpl<P: ChatPlatform + 'static> ChatAdapter<P>
impl<P: ChatPlatform + 'static> ChatAdapter<P>
pub fn new(platform: Arc<P>, channel_id: String) -> Self
pub fn with_shadow_default(self, shadow: bool) -> Self
Sourcepub async fn run(&self, rx: Receiver<WorkflowEvent>)
pub async fn run(&self, rx: Receiver<WorkflowEvent>)
Start listening to a broadcast channel of workflow events. Runs until the channel is closed or an error occurs.
Sourcepub async fn thread_for_execution(&self, execution_id: &str) -> Option<String>
pub async fn thread_for_execution(&self, execution_id: &str) -> Option<String>
Get the thread ID for an active execution.